@@ -24,7 +24,7 @@ class AddUsersToWorkGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AddInfo: 要操作的工作组和用户信息
         :type AddInfo: :class:`tencentcloud.dlc.v20210125.models.UserIdSetOfWorkGroupId`
         """
@@ -50,7 +50,7 @@ class AddUsersToWorkGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -67,8 +67,8 @@ class AttachUserPolicyRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param UserId: 用户Id，和CAM侧Uin匹配
+        r"""
+        :param UserId: 用户Id，和子用户uin相同，需要先使用CreateUser接口创建用户。可以使用DescribeUsers接口查看。
         :type UserId: str
         :param PolicySet: 鉴权策略集合
         :type PolicySet: list of Policy
@@ -100,7 +100,7 @@ class AttachUserPolicyResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -117,7 +117,7 @@ class AttachWorkGroupPolicyRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WorkGroupId: 工作组Id
         :type WorkGroupId: int
         :param PolicySet: 要绑定的策略集合
@@ -150,7 +150,7 @@ class AttachWorkGroupPolicyResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -167,7 +167,7 @@ class BindWorkGroupsToUserRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AddInfo: 绑定的用户和工作组信息
         :type AddInfo: :class:`tencentcloud.dlc.v20210125.models.WorkGroupIdSetOfUserId`
         """
@@ -193,7 +193,7 @@ class BindWorkGroupsToUserResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -210,7 +210,7 @@ class CSV(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CodeCompress: 压缩格式，["Snappy", "Gzip", "None"选一]。
         :type CodeCompress: str
         :param CSVSerde: CSV序列化及反序列化数据结构。
@@ -250,7 +250,7 @@ class CSVSerde(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Escape: CSV序列化转义符，默认为"\\"，最长8个字符，如 Escape: "/\"
         :type Escape: str
         :param Quote: CSV序列化字段域符，默认为"'"，最长8个字符, 如 Quote: "\""
@@ -282,7 +282,7 @@ class CancelTaskRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskId: 任务Id，全局唯一
         :type TaskId: str
         """
@@ -306,7 +306,7 @@ class CancelTaskResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -323,7 +323,7 @@ class Column(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 列名称，不区分大小写，最大支持25个字符。
         :type Name: str
         :param Type: 列类型，支持如下类型定义:
@@ -357,7 +357,7 @@ class CreateDatabaseRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseInfo: 数据库基础信息
         :type DatabaseInfo: :class:`tencentcloud.dlc.v20210125.models.DatabaseInfo`
         :param DatasourceConnectionName: 数据源名称，默认为CosDataCatalog
@@ -387,7 +387,7 @@ class CreateDatabaseResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Execution: 生成的建库执行语句对象。
         :type Execution: :class:`tencentcloud.dlc.v20210125.models.Execution`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -410,7 +410,7 @@ class CreateScriptRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ScriptName: 脚本名称，最大不能超过255个字符。
         :type ScriptName: str
         :param SQLStatement: base64编码后的sql语句
@@ -446,7 +446,7 @@ class CreateScriptResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -463,7 +463,7 @@ class CreateStoreLocationRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StoreLocation: 计算结果存储cos路径，如：cosn://bucketname/
         :type StoreLocation: str
         """
@@ -487,7 +487,7 @@ class CreateStoreLocationResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -504,7 +504,7 @@ class CreateTableRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TableInfo: 数据表配置信息
         :type TableInfo: :class:`tencentcloud.dlc.v20210125.models.TableInfo`
         """
@@ -530,7 +530,7 @@ class CreateTableResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Execution: 生成的建表执行语句对象。
         :type Execution: :class:`tencentcloud.dlc.v20210125.models.Execution`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -553,7 +553,7 @@ class CreateTaskRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Task: 计算任务，该参数中包含任务类型及其相关配置信息
         :type Task: :class:`tencentcloud.dlc.v20210125.models.Task`
         :param DatabaseName: 数据库名称。任务在执行前均会USE该数据库， 除了首次建库时，其他情况建议均添加上。
@@ -587,7 +587,7 @@ class CreateTaskResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskId: 任务ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type TaskId: str
@@ -603,16 +603,134 @@ class CreateTaskResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateTasksInOrderRequest(AbstractModel):
+    """CreateTasksInOrder请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param DatabaseName: 数据库名称。如果SQL语句中有数据库名称，优先使用SQL语句中的数据库，否则使用该参数指定的数据库。
+        :type DatabaseName: str
+        :param Tasks: SQL任务信息
+        :type Tasks: :class:`tencentcloud.dlc.v20210125.models.TasksInfo`
+        :param DatasourceConnectionName: 数据源名称，默认为COSDataCatalog
+        :type DatasourceConnectionName: str
+        """
+        self.DatabaseName = None
+        self.Tasks = None
+        self.DatasourceConnectionName = None
+
+
+    def _deserialize(self, params):
+        self.DatabaseName = params.get("DatabaseName")
+        if params.get("Tasks") is not None:
+            self.Tasks = TasksInfo()
+            self.Tasks._deserialize(params.get("Tasks"))
+        self.DatasourceConnectionName = params.get("DatasourceConnectionName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateTasksInOrderResponse(AbstractModel):
+    """CreateTasksInOrder返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param BatchId: 本批次提交的任务的批次Id
+        :type BatchId: str
+        :param TaskIdSet: 任务Id集合，按照执行顺序排列
+        :type TaskIdSet: list of str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.BatchId = None
+        self.TaskIdSet = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.BatchId = params.get("BatchId")
+        self.TaskIdSet = params.get("TaskIdSet")
+        self.RequestId = params.get("RequestId")
+
+
+class CreateTasksRequest(AbstractModel):
+    """CreateTasks请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param DatabaseName: 数据库名称。如果SQL语句中有数据库名称，优先使用SQL语句中的数据库，否则使用该参数指定的数据库。
+        :type DatabaseName: str
+        :param Tasks: SQL任务信息
+        :type Tasks: :class:`tencentcloud.dlc.v20210125.models.TasksInfo`
+        :param DatasourceConnectionName: 数据源名称，默认为COSDataCatalog
+        :type DatasourceConnectionName: str
+        """
+        self.DatabaseName = None
+        self.Tasks = None
+        self.DatasourceConnectionName = None
+
+
+    def _deserialize(self, params):
+        self.DatabaseName = params.get("DatabaseName")
+        if params.get("Tasks") is not None:
+            self.Tasks = TasksInfo()
+            self.Tasks._deserialize(params.get("Tasks"))
+        self.DatasourceConnectionName = params.get("DatasourceConnectionName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateTasksResponse(AbstractModel):
+    """CreateTasks返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param BatchId: 本批次提交的任务的批次Id
+        :type BatchId: str
+        :param TaskIdSet: 任务Id集合，按照执行顺序排列
+        :type TaskIdSet: list of str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.BatchId = None
+        self.TaskIdSet = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.BatchId = params.get("BatchId")
+        self.TaskIdSet = params.get("TaskIdSet")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateUserRequest(AbstractModel):
     """CreateUser请求参数结构体
 
     """
 
     def __init__(self):
-        """
-        :param UserId: 用户Id，当前主账号的子账号Uin，和CAM侧匹配
+        r"""
+        :param UserId: 需要授权的子用户uin，可以通过腾讯云控制台右上角 → “账号信息” → “账号ID进行查看”。
         :type UserId: str
-        :param UserDescription: 用户描述
+        :param UserDescription: 用户描述信息，方便区分不同用户
         :type UserDescription: str
         :param PolicySet: 绑定到用户的权限集合
         :type PolicySet: list of Policy
@@ -646,7 +764,7 @@ class CreateUserResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -663,7 +781,7 @@ class CreateWorkGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WorkGroupName: 工作组名称
         :type WorkGroupName: str
         :param WorkGroupDescription: 工作组描述
@@ -700,7 +818,7 @@ class CreateWorkGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WorkGroupId: 工作组Id，全局唯一
         :type WorkGroupId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -721,7 +839,7 @@ class DataFormat(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TextFile: 文本格式，TextFile。
 注意：此字段可能返回 null，表示取不到有效值。
         :type TextFile: :class:`tencentcloud.dlc.v20210125.models.TextFile`
@@ -783,7 +901,7 @@ class DatabaseInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseName: 数据库名称。
         :type DatabaseName: str
         :param Comment: 数据库描述信息，长度 0~256。
@@ -822,7 +940,7 @@ class DatabaseResponseInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseName: 数据库名称。
         :type DatabaseName: str
         :param Comment: 数据库描述信息，长度 0~256。
@@ -871,7 +989,7 @@ class DeleteScriptRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ScriptIds: 脚本id，其可以通过DescribeScripts接口提取
         :type ScriptIds: list of str
         """
@@ -895,7 +1013,7 @@ class DeleteScriptResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ScriptsAffected: 删除的脚本数量
         :type ScriptsAffected: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -916,7 +1034,7 @@ class DeleteUserRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserIds: 需要删除的用户的Id
         :type UserIds: list of str
         """
@@ -940,7 +1058,7 @@ class DeleteUserResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -957,7 +1075,7 @@ class DeleteUsersFromWorkGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AddInfo: 要删除的用户信息
         :type AddInfo: :class:`tencentcloud.dlc.v20210125.models.UserIdSetOfWorkGroupId`
         """
@@ -983,7 +1101,7 @@ class DeleteUsersFromWorkGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1000,7 +1118,7 @@ class DeleteWorkGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WorkGroupIds: 要删除的工作组Id集合
         :type WorkGroupIds: list of int
         """
@@ -1024,7 +1142,7 @@ class DeleteWorkGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1041,7 +1159,7 @@ class DescribeDatabasesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Limit: 返回数量，默认为10，最大值为100。
         :type Limit: int
         :param Offset: 数据偏移量，从0开始，默认为0。
@@ -1077,7 +1195,7 @@ class DescribeDatabasesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseList: 数据库对象列表。
         :type DatabaseList: list of DatabaseResponseInfo
         :param TotalCount: 实例总数。
@@ -1107,7 +1225,7 @@ class DescribeScriptsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Limit: 返回数量，默认为10，最大值为100。
         :type Limit: int
         :param Offset: 偏移量，默认为0。
@@ -1154,7 +1272,7 @@ class DescribeScriptsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Scripts: Script列表
 注意：此字段可能返回 null，表示取不到有效值。
         :type Scripts: list of Script
@@ -1191,7 +1309,7 @@ class DescribeStoreLocationResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StoreLocation: 返回用户设置的结果存储位置路径，如果未设置则返回空字符串：""
 注意：此字段可能返回 null，表示取不到有效值。
         :type StoreLocation: str
@@ -1213,7 +1331,7 @@ class DescribeTableRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TableName: 查询对象表名称
         :type TableName: str
         :param DatabaseName: 查询表所在的数据库名称。
@@ -1245,7 +1363,7 @@ class DescribeTableResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Table: 数据表对象
         :type Table: :class:`tencentcloud.dlc.v20210125.models.TableResponseInfo`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1268,7 +1386,7 @@ class DescribeTablesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseName: 列出该数据库下所属数据表。
         :type DatabaseName: str
         :param Limit: 返回数量，默认为10，最大值为100。
@@ -1315,7 +1433,7 @@ class DescribeTablesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TableList: 数据表对象列表。
         :type TableList: list of TableResponseInfo
         :param TotalCount: 实例总数。
@@ -1345,7 +1463,7 @@ class DescribeTasksRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Limit: 返回数量，默认为10，最大值为100。
         :type Limit: int
         :param Offset: 偏移量，默认为0。
@@ -1401,7 +1519,7 @@ class DescribeTasksResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskList: 任务对象列表。
         :type TaskList: list of TaskResponseInfo
         :param TotalCount: 实例总数。
@@ -1431,8 +1549,8 @@ class DescribeUsersRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param UserId: 查询的用户Id，和CAM侧Uin匹配
+        r"""
+        :param UserId: 指定查询的子用户uin，用户需要通过CreateUser接口创建。
         :type UserId: str
         :param Offset: 偏移量，默认为0
         :type Offset: int
@@ -1471,10 +1589,10 @@ class DescribeUsersResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param TotalCount: 用户总数
+        r"""
+        :param TotalCount: 查询到的用户总数
         :type TotalCount: int
-        :param UserSet: 用户集合
+        :param UserSet: 查询到的授权用户信息集合
         :type UserSet: list of UserInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -1501,7 +1619,7 @@ class DescribeViewsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseName: 列出该数据库下所属数据表。
         :type DatabaseName: str
         :param Limit: 返回数量，默认为10，最大值为100。
@@ -1548,7 +1666,7 @@ class DescribeViewsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ViewList: 视图对象列表。
         :type ViewList: list of ViewResponseInfo
         :param TotalCount: 实例总数。
@@ -1578,8 +1696,8 @@ class DescribeWorkGroupsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param WorkGroupId: 查询的工作组Id
+        r"""
+        :param WorkGroupId: 查询的工作组Id，不填或填0表示不过滤。
         :type WorkGroupId: int
         :param Filters: 过滤条件，当前仅支持按照工作组名称进行模糊搜索。Key为workgroup-name
         :type Filters: list of Filter
@@ -1627,7 +1745,7 @@ class DescribeWorkGroupsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 工作组总数
         :type TotalCount: int
         :param WorkGroupSet: 工作组信息集合
@@ -1657,7 +1775,7 @@ class DetachUserPolicyRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserId: 用户Id，和CAM侧Uin匹配
         :type UserId: str
         :param PolicySet: 解绑的权限集合
@@ -1690,7 +1808,7 @@ class DetachUserPolicyResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1707,7 +1825,7 @@ class DetachWorkGroupPolicyRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WorkGroupId: 工作组Id
         :type WorkGroupId: int
         :param PolicySet: 解绑的权限集合
@@ -1740,7 +1858,7 @@ class DetachWorkGroupPolicyResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1757,7 +1875,7 @@ class Execution(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SQL: 自动生成SQL语句。
         :type SQL: str
         """
@@ -1781,7 +1899,7 @@ class Filter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 属性名称, 若存在多个Filter时，Filter间的关系为逻辑或（OR）关系。
         :type Name: str
         :param Values: 属性值, 若同一个Filter存在多个Values，同一Filter下Values间的关系为逻辑或（OR）关系。
@@ -1809,7 +1927,7 @@ class KVPair(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Key: 配置的key值
 注意：此字段可能返回 null，表示取不到有效值。
         :type Key: str
@@ -1839,7 +1957,7 @@ class ModifyUserRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserId: 用户Id，和CAM侧Uin匹配
         :type UserId: str
         :param UserDescription: 用户描述
@@ -1867,7 +1985,7 @@ class ModifyUserResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1884,7 +2002,7 @@ class ModifyWorkGroupRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WorkGroupId: 工作组Id
         :type WorkGroupId: int
         :param WorkGroupDescription: 工作组描述
@@ -1912,7 +2030,7 @@ class ModifyWorkGroupResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1929,7 +2047,7 @@ class Other(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Format: 枚举类型，默认值为Json，可选值为[Json, Parquet, ORC, AVRD]之一。
         :type Format: str
         """
@@ -1953,7 +2071,7 @@ class Partition(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 分区列名。
         :type Name: str
         :param Type: 分区类型。
@@ -1985,14 +2103,14 @@ class Policy(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param Catalog: 需要授权的数据源名称，*代表拥有全部数据源权限
+        r"""
+        :param Catalog: 需要授权的数据源名称，当前仅支持COSDataCatalog或者*
         :type Catalog: str
-        :param Database: 需要授权的数据库名称，*代表拥有全部数据库名称
+        :param Database: 需要授权的数据库名，填*代表当前Catalog下所有数据库
         :type Database: str
-        :param Table: 需要授权的表名称，*代表拥有全部表权限
+        :param Table: 需要授权的表名，填*代表当前Database下所有表
         :type Table: str
-        :param Operation: 授权的操作，当前只支持“ALL”
+        :param Operation: 授权粒度，当前只支持ALL，即全部权限
         :type Operation: str
         """
         self.Catalog = None
@@ -2021,7 +2139,7 @@ class Property(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Key: 属性key名称。
         :type Key: str
         :param Value: 属性key对应的value。
@@ -2049,7 +2167,7 @@ class SQLTask(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SQL: base64加密后的SQL语句
         :type SQL: str
         :param Config: 任务的配置信息
@@ -2082,7 +2200,7 @@ class Script(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ScriptId: 脚本Id，长度36字节。
 注意：此字段可能返回 null，表示取不到有效值。
         :type ScriptId: str
@@ -2132,7 +2250,7 @@ class TableBaseInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseName: 该数据表所属数据库名字
         :type DatabaseName: str
         :param TableName: 数据表名字
@@ -2165,7 +2283,7 @@ class TableInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TableBaseInfo: 数据表配置信息。
         :type TableBaseInfo: :class:`tencentcloud.dlc.v20210125.models.TableBaseInfo`
         :param DataFormat: 数据表格式。每次入参可选如下其一的KV结构，[TextFile，CSV，Json, Parquet, ORC, AVRD]。
@@ -2219,7 +2337,7 @@ class TableResponseInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TableBaseInfo: 数据表基本信息。
         :type TableBaseInfo: :class:`tencentcloud.dlc.v20210125.models.TableBaseInfo`
         :param Columns: 数据表列信息。
@@ -2295,7 +2413,7 @@ class Task(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SQLTask: SQL查询任务
         :type SQLTask: :class:`tencentcloud.dlc.v20210125.models.SQLTask`
         :param SparkSQLTask: Spark SQL查询任务
@@ -2322,12 +2440,12 @@ class Task(AbstractModel):
 
 
 class TaskResponseInfo(AbstractModel):
-    """任务实例。
+    """任务实例
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseName: 任务所属Database的名称。
         :type DatabaseName: str
         :param DataAmount: 任务数据量。
@@ -2340,7 +2458,7 @@ class TaskResponseInfo(AbstractModel):
         :type OutputPath: str
         :param CreateTime: 任务创建时间。
         :type CreateTime: str
-        :param State: 任务状态, 0 初始化， 1 执行中， 2 执行成功，3 数据写入中，-1 执行失败。
+        :param State: 任务状态：0 初始化， 1 执行中， 2 执行成功，-1 执行失败，-3 已取消。
         :type State: int
         :param SQLType: 任务SQL类型，DDL|DML等
         :type SQLType: str
@@ -2361,6 +2479,9 @@ class TaskResponseInfo(AbstractModel):
         :type OutputMessage: str
         :param TaskType: 执行SQL的引擎类型
         :type TaskType: str
+        :param ProgressDetail: 任务进度明细
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ProgressDetail: str
         """
         self.DatabaseName = None
         self.DataAmount = None
@@ -2378,6 +2499,7 @@ class TaskResponseInfo(AbstractModel):
         self.Percentage = None
         self.OutputMessage = None
         self.TaskType = None
+        self.ProgressDetail = None
 
 
     def _deserialize(self, params):
@@ -2397,6 +2519,48 @@ class TaskResponseInfo(AbstractModel):
         self.Percentage = params.get("Percentage")
         self.OutputMessage = params.get("OutputMessage")
         self.TaskType = params.get("TaskType")
+        self.ProgressDetail = params.get("ProgressDetail")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class TasksInfo(AbstractModel):
+    """批量顺序执行任务集合
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskType: 任务类型，SQLTask：SQL查询任务。SparkSQLTask：Spark SQL查询任务
+        :type TaskType: str
+        :param FailureTolerance: 容错策略。Proceed：前面任务出错/取消后继续执行后面的任务。Terminate：前面的任务出错/取消之后终止后面任务的执行，后面的任务全部标记为已取消。
+        :type FailureTolerance: str
+        :param SQL: base64加密后的SQL语句，用";"号分隔每个SQL语句，一次最多提交50个任务。严格按照前后顺序执行
+        :type SQL: str
+        :param Config: 任务的配置信息，当前仅支持SparkSQLTask任务。
+        :type Config: list of KVPair
+        """
+        self.TaskType = None
+        self.FailureTolerance = None
+        self.SQL = None
+        self.Config = None
+
+
+    def _deserialize(self, params):
+        self.TaskType = params.get("TaskType")
+        self.FailureTolerance = params.get("FailureTolerance")
+        self.SQL = params.get("SQL")
+        if params.get("Config") is not None:
+            self.Config = []
+            for item in params.get("Config"):
+                obj = KVPair()
+                obj._deserialize(item)
+                self.Config.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2412,7 +2576,7 @@ class TextFile(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Format: 文本类型，本参数取值为TextFile。
         :type Format: str
         :param Regex: 处理文本用的正则表达式。
@@ -2441,7 +2605,7 @@ class UnbindWorkGroupsFromUserRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AddInfo: 解绑的工作组Id和用户Id的关联关系
         :type AddInfo: :class:`tencentcloud.dlc.v20210125.models.WorkGroupIdSetOfUserId`
         """
@@ -2467,7 +2631,7 @@ class UnbindWorkGroupsFromUserResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -2484,7 +2648,7 @@ class UserIdSetOfWorkGroupId(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WorkGroupId: 工作组Id
         :type WorkGroupId: int
         :param UserIds: 用户Id集合，和CAM侧Uin匹配
@@ -2512,18 +2676,18 @@ class UserInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param UserId: 用户Id，和CAM侧Uin匹配
+        r"""
+        :param UserId: 用户Id，和子用户uin相同
         :type UserId: str
-        :param UserDescription: 用户描述
+        :param UserDescription: 用户描述信息，方便区分不同用户
 注意：此字段可能返回 null，表示取不到有效值。
         :type UserDescription: str
         :param PolicySet: 单独给用户绑定的权限集合
 注意：此字段可能返回 null，表示取不到有效值。
         :type PolicySet: list of Policy
-        :param Creator: 创建者
+        :param Creator: 当前用户的创建者
         :type Creator: str
-        :param CreateTime: 创建时间
+        :param CreateTime: 创建时间，格式如2021-07-28 16:19:32
         :type CreateTime: str
         :param WorkGroupSet: 关联的工作组集合
 注意：此字段可能返回 null，表示取不到有效值。
@@ -2574,15 +2738,15 @@ class UserMessage(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param UserId: 用户Id，和CAM侧Uin匹配
+        r"""
+        :param UserId: 用户Id，和CAM侧子用户Uin匹配
         :type UserId: str
         :param UserDescription: 用户描述
 注意：此字段可能返回 null，表示取不到有效值。
         :type UserDescription: str
-        :param Creator: 创建者
+        :param Creator: 当前用户的创建者
         :type Creator: str
-        :param CreateTime: 创建时间
+        :param CreateTime: 当前用户的创建时间，形如2021-07-28 16:19:32
         :type CreateTime: str
         """
         self.UserId = None
@@ -2611,7 +2775,7 @@ class ViewBaseInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DatabaseName: 该视图所属数据库名字
         :type DatabaseName: str
         :param ViewName: 视图名称
@@ -2639,7 +2803,7 @@ class ViewResponseInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ViewBaseInfo: 视图基本信息。
         :type ViewBaseInfo: :class:`tencentcloud.dlc.v20210125.models.ViewBaseInfo`
         :param Columns: 视图列信息。
@@ -2693,7 +2857,7 @@ class WorkGroupIdSetOfUserId(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserId: 用户Id，和CAM侧Uin匹配
         :type UserId: str
         :param WorkGroupIds: 工作组Id集合
@@ -2721,8 +2885,8 @@ class WorkGroupInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param WorkGroupId: 工作组Id
+        r"""
+        :param WorkGroupId: 查询到的工作组唯一Id
         :type WorkGroupId: int
         :param WorkGroupName: 工作组名称
         :type WorkGroupName: str
@@ -2737,9 +2901,9 @@ class WorkGroupInfo(AbstractModel):
         :param PolicySet: 工作组绑定的权限集合
 注意：此字段可能返回 null，表示取不到有效值。
         :type PolicySet: list of Policy
-        :param Creator: 创建者
+        :param Creator: 工作组的创建人
         :type Creator: str
-        :param CreateTime: 创建时间
+        :param CreateTime: 工作组的创建时间，形如2021-07-28 16:19:32
         :type CreateTime: str
         """
         self.WorkGroupId = None
@@ -2786,8 +2950,8 @@ class WorkGroupMessage(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param WorkGroupId: 工作组Id
+        r"""
+        :param WorkGroupId: 工作组唯一Id
         :type WorkGroupId: int
         :param WorkGroupName: 工作组名称
         :type WorkGroupName: str
@@ -2796,7 +2960,7 @@ class WorkGroupMessage(AbstractModel):
         :type WorkGroupDescription: str
         :param Creator: 创建者
         :type Creator: str
-        :param CreateTime: 创建时间
+        :param CreateTime: 工作组创建的时间，形如2021-07-28 16:19:32
         :type CreateTime: str
         """
         self.WorkGroupId = None
